# graphicle

![Tests](https://github.com/jacanchaplais/graphicle/actions/workflows/tests.yml/badge.svg)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

Utilities for representing high energy physics data as graphs / networks.

# Features
- Calculate affinity matrices from 4-momenta
- Produce adjacency matrices from the affinity
  - k-nearest neighbours (weighted optional)
  - fully connected

## Installation
```
pip install graphicle
```

# Coming soon
- [ ] Documentation
